# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class QuestionGroupScore(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QuestionGroupScore - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'question_group_id': 'str',
            'total_score': 'float',
            'max_total_score': 'float',
            'total_critical_score': 'float',
            'max_total_critical_score': 'float',
            'total_score_unweighted': 'float',
            'max_total_score_unweighted': 'float',
            'total_critical_score_unweighted': 'float',
            'max_total_critical_score_unweighted': 'float',
            'marked_na': 'bool',
            'question_scores': 'list[QuestionScore]'
        }

        self.attribute_map = {
            'question_group_id': 'questionGroupId',
            'total_score': 'totalScore',
            'max_total_score': 'maxTotalScore',
            'total_critical_score': 'totalCriticalScore',
            'max_total_critical_score': 'maxTotalCriticalScore',
            'total_score_unweighted': 'totalScoreUnweighted',
            'max_total_score_unweighted': 'maxTotalScoreUnweighted',
            'total_critical_score_unweighted': 'totalCriticalScoreUnweighted',
            'max_total_critical_score_unweighted': 'maxTotalCriticalScoreUnweighted',
            'marked_na': 'markedNA',
            'question_scores': 'questionScores'
        }

        self._question_group_id = None
        self._total_score = None
        self._max_total_score = None
        self._total_critical_score = None
        self._max_total_critical_score = None
        self._total_score_unweighted = None
        self._max_total_score_unweighted = None
        self._total_critical_score_unweighted = None
        self._max_total_critical_score_unweighted = None
        self._marked_na = False
        self._question_scores = None

    @property
    def question_group_id(self):
        """
        Gets the question_group_id of this QuestionGroupScore.


        :return: The question_group_id of this QuestionGroupScore.
        :rtype: str
        """
        return self._question_group_id

    @question_group_id.setter
    def question_group_id(self, question_group_id):
        """
        Sets the question_group_id of this QuestionGroupScore.


        :param question_group_id: The question_group_id of this QuestionGroupScore.
        :type: str
        """
        
        self._question_group_id = question_group_id

    @property
    def total_score(self):
        """
        Gets the total_score of this QuestionGroupScore.


        :return: The total_score of this QuestionGroupScore.
        :rtype: float
        """
        return self._total_score

    @total_score.setter
    def total_score(self, total_score):
        """
        Sets the total_score of this QuestionGroupScore.


        :param total_score: The total_score of this QuestionGroupScore.
        :type: float
        """
        
        self._total_score = total_score

    @property
    def max_total_score(self):
        """
        Gets the max_total_score of this QuestionGroupScore.


        :return: The max_total_score of this QuestionGroupScore.
        :rtype: float
        """
        return self._max_total_score

    @max_total_score.setter
    def max_total_score(self, max_total_score):
        """
        Sets the max_total_score of this QuestionGroupScore.


        :param max_total_score: The max_total_score of this QuestionGroupScore.
        :type: float
        """
        
        self._max_total_score = max_total_score

    @property
    def total_critical_score(self):
        """
        Gets the total_critical_score of this QuestionGroupScore.


        :return: The total_critical_score of this QuestionGroupScore.
        :rtype: float
        """
        return self._total_critical_score

    @total_critical_score.setter
    def total_critical_score(self, total_critical_score):
        """
        Sets the total_critical_score of this QuestionGroupScore.


        :param total_critical_score: The total_critical_score of this QuestionGroupScore.
        :type: float
        """
        
        self._total_critical_score = total_critical_score

    @property
    def max_total_critical_score(self):
        """
        Gets the max_total_critical_score of this QuestionGroupScore.


        :return: The max_total_critical_score of this QuestionGroupScore.
        :rtype: float
        """
        return self._max_total_critical_score

    @max_total_critical_score.setter
    def max_total_critical_score(self, max_total_critical_score):
        """
        Sets the max_total_critical_score of this QuestionGroupScore.


        :param max_total_critical_score: The max_total_critical_score of this QuestionGroupScore.
        :type: float
        """
        
        self._max_total_critical_score = max_total_critical_score

    @property
    def total_score_unweighted(self):
        """
        Gets the total_score_unweighted of this QuestionGroupScore.


        :return: The total_score_unweighted of this QuestionGroupScore.
        :rtype: float
        """
        return self._total_score_unweighted

    @total_score_unweighted.setter
    def total_score_unweighted(self, total_score_unweighted):
        """
        Sets the total_score_unweighted of this QuestionGroupScore.


        :param total_score_unweighted: The total_score_unweighted of this QuestionGroupScore.
        :type: float
        """
        
        self._total_score_unweighted = total_score_unweighted

    @property
    def max_total_score_unweighted(self):
        """
        Gets the max_total_score_unweighted of this QuestionGroupScore.


        :return: The max_total_score_unweighted of this QuestionGroupScore.
        :rtype: float
        """
        return self._max_total_score_unweighted

    @max_total_score_unweighted.setter
    def max_total_score_unweighted(self, max_total_score_unweighted):
        """
        Sets the max_total_score_unweighted of this QuestionGroupScore.


        :param max_total_score_unweighted: The max_total_score_unweighted of this QuestionGroupScore.
        :type: float
        """
        
        self._max_total_score_unweighted = max_total_score_unweighted

    @property
    def total_critical_score_unweighted(self):
        """
        Gets the total_critical_score_unweighted of this QuestionGroupScore.


        :return: The total_critical_score_unweighted of this QuestionGroupScore.
        :rtype: float
        """
        return self._total_critical_score_unweighted

    @total_critical_score_unweighted.setter
    def total_critical_score_unweighted(self, total_critical_score_unweighted):
        """
        Sets the total_critical_score_unweighted of this QuestionGroupScore.


        :param total_critical_score_unweighted: The total_critical_score_unweighted of this QuestionGroupScore.
        :type: float
        """
        
        self._total_critical_score_unweighted = total_critical_score_unweighted

    @property
    def max_total_critical_score_unweighted(self):
        """
        Gets the max_total_critical_score_unweighted of this QuestionGroupScore.


        :return: The max_total_critical_score_unweighted of this QuestionGroupScore.
        :rtype: float
        """
        return self._max_total_critical_score_unweighted

    @max_total_critical_score_unweighted.setter
    def max_total_critical_score_unweighted(self, max_total_critical_score_unweighted):
        """
        Sets the max_total_critical_score_unweighted of this QuestionGroupScore.


        :param max_total_critical_score_unweighted: The max_total_critical_score_unweighted of this QuestionGroupScore.
        :type: float
        """
        
        self._max_total_critical_score_unweighted = max_total_critical_score_unweighted

    @property
    def marked_na(self):
        """
        Gets the marked_na of this QuestionGroupScore.


        :return: The marked_na of this QuestionGroupScore.
        :rtype: bool
        """
        return self._marked_na

    @marked_na.setter
    def marked_na(self, marked_na):
        """
        Sets the marked_na of this QuestionGroupScore.


        :param marked_na: The marked_na of this QuestionGroupScore.
        :type: bool
        """
        
        self._marked_na = marked_na

    @property
    def question_scores(self):
        """
        Gets the question_scores of this QuestionGroupScore.


        :return: The question_scores of this QuestionGroupScore.
        :rtype: list[QuestionScore]
        """
        return self._question_scores

    @question_scores.setter
    def question_scores(self, question_scores):
        """
        Sets the question_scores of this QuestionGroupScore.


        :param question_scores: The question_scores of this QuestionGroupScore.
        :type: list[QuestionScore]
        """
        
        self._question_scores = question_scores

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class CreateShareRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CreateShareRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'shared_entity_type': 'str',
            'shared_entity': 'SharedEntity',
            'member_type': 'str',
            'member': 'SharedEntity',
            'members': 'list[CreateShareRequestMember]'
        }

        self.attribute_map = {
            'shared_entity_type': 'sharedEntityType',
            'shared_entity': 'sharedEntity',
            'member_type': 'memberType',
            'member': 'member',
            'members': 'members'
        }

        self._shared_entity_type = None
        self._shared_entity = None
        self._member_type = None
        self._member = None
        self._members = None

    @property
    def shared_entity_type(self):
        """
        Gets the shared_entity_type of this CreateShareRequest.


        :return: The shared_entity_type of this CreateShareRequest.
        :rtype: str
        """
        return self._shared_entity_type

    @shared_entity_type.setter
    def shared_entity_type(self, shared_entity_type):
        """
        Sets the shared_entity_type of this CreateShareRequest.


        :param shared_entity_type: The shared_entity_type of this CreateShareRequest.
        :type: str
        """
        allowed_values = ["DOCUMENT"]
        if shared_entity_type not in allowed_values:
            raise ValueError(
                "Invalid value for `shared_entity_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._shared_entity_type = shared_entity_type

    @property
    def shared_entity(self):
        """
        Gets the shared_entity of this CreateShareRequest.


        :return: The shared_entity of this CreateShareRequest.
        :rtype: SharedEntity
        """
        return self._shared_entity

    @shared_entity.setter
    def shared_entity(self, shared_entity):
        """
        Sets the shared_entity of this CreateShareRequest.


        :param shared_entity: The shared_entity of this CreateShareRequest.
        :type: SharedEntity
        """
        
        self._shared_entity = shared_entity

    @property
    def member_type(self):
        """
        Gets the member_type of this CreateShareRequest.


        :return: The member_type of this CreateShareRequest.
        :rtype: str
        """
        return self._member_type

    @member_type.setter
    def member_type(self, member_type):
        """
        Sets the member_type of this CreateShareRequest.


        :param member_type: The member_type of this CreateShareRequest.
        :type: str
        """
        allowed_values = ["USER", "GROUP", "PUBLIC"]
        if member_type not in allowed_values:
            raise ValueError(
                "Invalid value for `member_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._member_type = member_type

    @property
    def member(self):
        """
        Gets the member of this CreateShareRequest.


        :return: The member of this CreateShareRequest.
        :rtype: SharedEntity
        """
        return self._member

    @member.setter
    def member(self, member):
        """
        Sets the member of this CreateShareRequest.


        :param member: The member of this CreateShareRequest.
        :type: SharedEntity
        """
        
        self._member = member

    @property
    def members(self):
        """
        Gets the members of this CreateShareRequest.


        :return: The members of this CreateShareRequest.
        :rtype: list[CreateShareRequestMember]
        """
        return self._members

    @members.setter
    def members(self, members):
        """
        Sets the members of this CreateShareRequest.


        :param members: The members of this CreateShareRequest.
        :type: list[CreateShareRequestMember]
        """
        
        self._members = members

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class ContactList(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ContactList - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'version': 'int',
            'column_names': 'list[str]',
            'phone_columns': 'list[ContactPhoneNumberColumn]',
            'import_status': 'ImportStatus',
            'preview_mode_column_name': 'str',
            'preview_mode_accepted_values': 'list[str]',
            'size': 'int',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'version': 'version',
            'column_names': 'columnNames',
            'phone_columns': 'phoneColumns',
            'import_status': 'importStatus',
            'preview_mode_column_name': 'previewModeColumnName',
            'preview_mode_accepted_values': 'previewModeAcceptedValues',
            'size': 'size',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._version = None
        self._column_names = None
        self._phone_columns = None
        self._import_status = None
        self._preview_mode_column_name = None
        self._preview_mode_accepted_values = None
        self._size = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this ContactList.
        The globally unique identifier for the object.

        :return: The id of this ContactList.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ContactList.
        The globally unique identifier for the object.

        :param id: The id of this ContactList.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ContactList.


        :return: The name of this ContactList.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ContactList.


        :param name: The name of this ContactList.
        :type: str
        """
        
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this ContactList.
        Creation time of the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this ContactList.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this ContactList.
        Creation time of the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this ContactList.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this ContactList.
        Last modified time of the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this ContactList.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this ContactList.
        Last modified time of the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this ContactList.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def version(self):
        """
        Gets the version of this ContactList.
        Required for updates, must match the version number of the most recent update

        :return: The version of this ContactList.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this ContactList.
        Required for updates, must match the version number of the most recent update

        :param version: The version of this ContactList.
        :type: int
        """
        
        self._version = version

    @property
    def column_names(self):
        """
        Gets the column_names of this ContactList.
        the contact column names

        :return: The column_names of this ContactList.
        :rtype: list[str]
        """
        return self._column_names

    @column_names.setter
    def column_names(self, column_names):
        """
        Sets the column_names of this ContactList.
        the contact column names

        :param column_names: The column_names of this ContactList.
        :type: list[str]
        """
        
        self._column_names = column_names

    @property
    def phone_columns(self):
        """
        Gets the phone_columns of this ContactList.
        the columns containing phone numbers

        :return: The phone_columns of this ContactList.
        :rtype: list[ContactPhoneNumberColumn]
        """
        return self._phone_columns

    @phone_columns.setter
    def phone_columns(self, phone_columns):
        """
        Sets the phone_columns of this ContactList.
        the columns containing phone numbers

        :param phone_columns: The phone_columns of this ContactList.
        :type: list[ContactPhoneNumberColumn]
        """
        
        self._phone_columns = phone_columns

    @property
    def import_status(self):
        """
        Gets the import_status of this ContactList.
        the status of the import process

        :return: The import_status of this ContactList.
        :rtype: ImportStatus
        """
        return self._import_status

    @import_status.setter
    def import_status(self, import_status):
        """
        Sets the import_status of this ContactList.
        the status of the import process

        :param import_status: The import_status of this ContactList.
        :type: ImportStatus
        """
        
        self._import_status = import_status

    @property
    def preview_mode_column_name(self):
        """
        Gets the preview_mode_column_name of this ContactList.
        the name of the column that holds the indicators for contacts that are to be dialed in preview mode only

        :return: The preview_mode_column_name of this ContactList.
        :rtype: str
        """
        return self._preview_mode_column_name

    @preview_mode_column_name.setter
    def preview_mode_column_name(self, preview_mode_column_name):
        """
        Sets the preview_mode_column_name of this ContactList.
        the name of the column that holds the indicators for contacts that are to be dialed in preview mode only

        :param preview_mode_column_name: The preview_mode_column_name of this ContactList.
        :type: str
        """
        
        self._preview_mode_column_name = preview_mode_column_name

    @property
    def preview_mode_accepted_values(self):
        """
        Gets the preview_mode_accepted_values of this ContactList.
        list of user-defined values indicating the contact is to be dialed in preview mode only

        :return: The preview_mode_accepted_values of this ContactList.
        :rtype: list[str]
        """
        return self._preview_mode_accepted_values

    @preview_mode_accepted_values.setter
    def preview_mode_accepted_values(self, preview_mode_accepted_values):
        """
        Sets the preview_mode_accepted_values of this ContactList.
        list of user-defined values indicating the contact is to be dialed in preview mode only

        :param preview_mode_accepted_values: The preview_mode_accepted_values of this ContactList.
        :type: list[str]
        """
        
        self._preview_mode_accepted_values = preview_mode_accepted_values

    @property
    def size(self):
        """
        Gets the size of this ContactList.
        the number of contacts in the contact list

        :return: The size of this ContactList.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this ContactList.
        the number of contacts in the contact list

        :param size: The size of this ContactList.
        :type: int
        """
        
        self._size = size

    @property
    def self_uri(self):
        """
        Gets the self_uri of this ContactList.
        The URI for this object

        :return: The self_uri of this ContactList.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this ContactList.
        The URI for this object

        :param self_uri: The self_uri of this ContactList.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class EmailMediaParticipant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        EmailMediaParticipant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'address': 'str',
            'start_time': 'datetime',
            'connected_time': 'datetime',
            'end_time': 'datetime',
            'start_hold_time': 'datetime',
            'purpose': 'str',
            'state': 'str',
            'direction': 'str',
            'disconnect_type': 'str',
            'held': 'bool',
            'wrapup_required': 'bool',
            'wrapup_prompt': 'str',
            'user': 'UriReference',
            'queue': 'UriReference',
            'attributes': 'dict(str, str)',
            'error_info': 'ErrorBody',
            'script': 'UriReference',
            'wrapup_timeout_ms': 'int',
            'wrapup_skipped': 'bool',
            'subject': 'str',
            'messages_sent': 'int'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'address': 'address',
            'start_time': 'startTime',
            'connected_time': 'connectedTime',
            'end_time': 'endTime',
            'start_hold_time': 'startHoldTime',
            'purpose': 'purpose',
            'state': 'state',
            'direction': 'direction',
            'disconnect_type': 'disconnectType',
            'held': 'held',
            'wrapup_required': 'wrapupRequired',
            'wrapup_prompt': 'wrapupPrompt',
            'user': 'user',
            'queue': 'queue',
            'attributes': 'attributes',
            'error_info': 'errorInfo',
            'script': 'script',
            'wrapup_timeout_ms': 'wrapupTimeoutMs',
            'wrapup_skipped': 'wrapupSkipped',
            'subject': 'subject',
            'messages_sent': 'messagesSent'
        }

        self._id = None
        self._name = None
        self._address = None
        self._start_time = None
        self._connected_time = None
        self._end_time = None
        self._start_hold_time = None
        self._purpose = None
        self._state = None
        self._direction = None
        self._disconnect_type = None
        self._held = False
        self._wrapup_required = False
        self._wrapup_prompt = None
        self._user = None
        self._queue = None
        self._attributes = None
        self._error_info = None
        self._script = None
        self._wrapup_timeout_ms = None
        self._wrapup_skipped = False
        self._subject = None
        self._messages_sent = None

    @property
    def id(self):
        """
        Gets the id of this EmailMediaParticipant.
        The unique participant ID.

        :return: The id of this EmailMediaParticipant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this EmailMediaParticipant.
        The unique participant ID.

        :param id: The id of this EmailMediaParticipant.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this EmailMediaParticipant.
        The display friendly name of the participant.

        :return: The name of this EmailMediaParticipant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this EmailMediaParticipant.
        The display friendly name of the participant.

        :param name: The name of this EmailMediaParticipant.
        :type: str
        """
        
        self._name = name

    @property
    def address(self):
        """
        Gets the address of this EmailMediaParticipant.
        The participant address.

        :return: The address of this EmailMediaParticipant.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this EmailMediaParticipant.
        The participant address.

        :param address: The address of this EmailMediaParticipant.
        :type: str
        """
        
        self._address = address

    @property
    def start_time(self):
        """
        Gets the start_time of this EmailMediaParticipant.
        The time when this participant joined the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The start_time of this EmailMediaParticipant.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this EmailMediaParticipant.
        The time when this participant joined the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param start_time: The start_time of this EmailMediaParticipant.
        :type: datetime
        """
        
        self._start_time = start_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this EmailMediaParticipant.
        The time when this participant went connected on the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The connected_time of this EmailMediaParticipant.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this EmailMediaParticipant.
        The time when this participant went connected on the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param connected_time: The connected_time of this EmailMediaParticipant.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def end_time(self):
        """
        Gets the end_time of this EmailMediaParticipant.
        The time when this participant when disconnected on the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The end_time of this EmailMediaParticipant.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this EmailMediaParticipant.
        The time when this participant when disconnected on the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param end_time: The end_time of this EmailMediaParticipant.
        :type: datetime
        """
        
        self._end_time = end_time

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this EmailMediaParticipant.
        The time when this participant's hold started. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The start_hold_time of this EmailMediaParticipant.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this EmailMediaParticipant.
        The time when this participant's hold started. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param start_hold_time: The start_hold_time of this EmailMediaParticipant.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def purpose(self):
        """
        Gets the purpose of this EmailMediaParticipant.
        The participant's purpose.  Values can be: 'agent', 'user', 'customer', 'external', 'acd', 'ivr

        :return: The purpose of this EmailMediaParticipant.
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """
        Sets the purpose of this EmailMediaParticipant.
        The participant's purpose.  Values can be: 'agent', 'user', 'customer', 'external', 'acd', 'ivr

        :param purpose: The purpose of this EmailMediaParticipant.
        :type: str
        """
        
        self._purpose = purpose

    @property
    def state(self):
        """
        Gets the state of this EmailMediaParticipant.
        The participant's state.  Values can be: 'alerting', 'connected', 'disconnected', 'dialing', 'contacting

        :return: The state of this EmailMediaParticipant.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this EmailMediaParticipant.
        The participant's state.  Values can be: 'alerting', 'connected', 'disconnected', 'dialing', 'contacting

        :param state: The state of this EmailMediaParticipant.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "CONVERTING", "UPLOADING", "TRANSMITTING", "NONE"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )

        self._state = state

    @property
    def direction(self):
        """
        Gets the direction of this EmailMediaParticipant.
        The participant's direction.  Values can be: 'inbound' or 'outbound'

        :return: The direction of this EmailMediaParticipant.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this EmailMediaParticipant.
        The participant's direction.  Values can be: 'inbound' or 'outbound'

        :param direction: The direction of this EmailMediaParticipant.
        :type: str
        """
        allowed_values = ["INBOUND", "OUTBOUND"]
        if direction not in allowed_values:
            raise ValueError(
                "Invalid value for `direction`, must be one of {0}"
                .format(allowed_values)
            )

        self._direction = direction

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this EmailMediaParticipant.
        The reason the participant was disconnected from the conversation.

        :return: The disconnect_type of this EmailMediaParticipant.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this EmailMediaParticipant.
        The reason the participant was disconnected from the conversation.

        :param disconnect_type: The disconnect_type of this EmailMediaParticipant.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "ERROR", "PEER", "OTHER"]
        if disconnect_type not in allowed_values:
            raise ValueError(
                "Invalid value for `disconnect_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._disconnect_type = disconnect_type

    @property
    def held(self):
        """
        Gets the held of this EmailMediaParticipant.
        Value is true when the participant is on hold.

        :return: The held of this EmailMediaParticipant.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this EmailMediaParticipant.
        Value is true when the participant is on hold.

        :param held: The held of this EmailMediaParticipant.
        :type: bool
        """
        
        self._held = held

    @property
    def wrapup_required(self):
        """
        Gets the wrapup_required of this EmailMediaParticipant.
        Value is true when the participant requires wrap-up.

        :return: The wrapup_required of this EmailMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_required

    @wrapup_required.setter
    def wrapup_required(self, wrapup_required):
        """
        Sets the wrapup_required of this EmailMediaParticipant.
        Value is true when the participant requires wrap-up.

        :param wrapup_required: The wrapup_required of this EmailMediaParticipant.
        :type: bool
        """
        
        self._wrapup_required = wrapup_required

    @property
    def wrapup_prompt(self):
        """
        Gets the wrapup_prompt of this EmailMediaParticipant.
        The wrap-up prompt indicating the type of wrap-up to be performed.

        :return: The wrapup_prompt of this EmailMediaParticipant.
        :rtype: str
        """
        return self._wrapup_prompt

    @wrapup_prompt.setter
    def wrapup_prompt(self, wrapup_prompt):
        """
        Sets the wrapup_prompt of this EmailMediaParticipant.
        The wrap-up prompt indicating the type of wrap-up to be performed.

        :param wrapup_prompt: The wrapup_prompt of this EmailMediaParticipant.
        :type: str
        """
        
        self._wrapup_prompt = wrapup_prompt

    @property
    def user(self):
        """
        Gets the user of this EmailMediaParticipant.
        The PureCloud user for this participant.

        :return: The user of this EmailMediaParticipant.
        :rtype: UriReference
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this EmailMediaParticipant.
        The PureCloud user for this participant.

        :param user: The user of this EmailMediaParticipant.
        :type: UriReference
        """
        
        self._user = user

    @property
    def queue(self):
        """
        Gets the queue of this EmailMediaParticipant.
        The PureCloud queue for this participant.

        :return: The queue of this EmailMediaParticipant.
        :rtype: UriReference
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this EmailMediaParticipant.
        The PureCloud queue for this participant.

        :param queue: The queue of this EmailMediaParticipant.
        :type: UriReference
        """
        
        self._queue = queue

    @property
    def attributes(self):
        """
        Gets the attributes of this EmailMediaParticipant.
        A list of ad-hoc attributes for the participant.

        :return: The attributes of this EmailMediaParticipant.
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this EmailMediaParticipant.
        A list of ad-hoc attributes for the participant.

        :param attributes: The attributes of this EmailMediaParticipant.
        :type: dict(str, str)
        """
        
        self._attributes = attributes

    @property
    def error_info(self):
        """
        Gets the error_info of this EmailMediaParticipant.
        If the conversation ends in error, contains additional error details.

        :return: The error_info of this EmailMediaParticipant.
        :rtype: ErrorBody
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this EmailMediaParticipant.
        If the conversation ends in error, contains additional error details.

        :param error_info: The error_info of this EmailMediaParticipant.
        :type: ErrorBody
        """
        
        self._error_info = error_info

    @property
    def script(self):
        """
        Gets the script of this EmailMediaParticipant.
        The Engage script that should be used by this participant.

        :return: The script of this EmailMediaParticipant.
        :rtype: UriReference
        """
        return self._script

    @script.setter
    def script(self, script):
        """
        Sets the script of this EmailMediaParticipant.
        The Engage script that should be used by this participant.

        :param script: The script of this EmailMediaParticipant.
        :type: UriReference
        """
        
        self._script = script

    @property
    def wrapup_timeout_ms(self):
        """
        Gets the wrapup_timeout_ms of this EmailMediaParticipant.
        The amount of time the participant has to complete wrap-up.

        :return: The wrapup_timeout_ms of this EmailMediaParticipant.
        :rtype: int
        """
        return self._wrapup_timeout_ms

    @wrapup_timeout_ms.setter
    def wrapup_timeout_ms(self, wrapup_timeout_ms):
        """
        Sets the wrapup_timeout_ms of this EmailMediaParticipant.
        The amount of time the participant has to complete wrap-up.

        :param wrapup_timeout_ms: The wrapup_timeout_ms of this EmailMediaParticipant.
        :type: int
        """
        
        self._wrapup_timeout_ms = wrapup_timeout_ms

    @property
    def wrapup_skipped(self):
        """
        Gets the wrapup_skipped of this EmailMediaParticipant.
        Value is true when the participant has skipped wrap-up.

        :return: The wrapup_skipped of this EmailMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_skipped

    @wrapup_skipped.setter
    def wrapup_skipped(self, wrapup_skipped):
        """
        Sets the wrapup_skipped of this EmailMediaParticipant.
        Value is true when the participant has skipped wrap-up.

        :param wrapup_skipped: The wrapup_skipped of this EmailMediaParticipant.
        :type: bool
        """
        
        self._wrapup_skipped = wrapup_skipped

    @property
    def subject(self):
        """
        Gets the subject of this EmailMediaParticipant.
        The subject of the email.

        :return: The subject of this EmailMediaParticipant.
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this EmailMediaParticipant.
        The subject of the email.

        :param subject: The subject of this EmailMediaParticipant.
        :type: str
        """
        
        self._subject = subject

    @property
    def messages_sent(self):
        """
        Gets the messages_sent of this EmailMediaParticipant.
        The number of messages that have been sent in this email conversation.

        :return: The messages_sent of this EmailMediaParticipant.
        :rtype: int
        """
        return self._messages_sent

    @messages_sent.setter
    def messages_sent(self, messages_sent):
        """
        Sets the messages_sent of this EmailMediaParticipant.
        The number of messages that have been sent in this email conversation.

        :param messages_sent: The messages_sent of this EmailMediaParticipant.
        :type: int
        """
        
        self._messages_sent = messages_sent

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class Station(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Station - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'status': 'str',
            'user_id': 'str',
            'primary_edge': 'UriReference',
            'secondary_edge': 'UriReference',
            'type': 'str',
            'line_appearance_id': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'status': 'status',
            'user_id': 'userId',
            'primary_edge': 'primaryEdge',
            'secondary_edge': 'secondaryEdge',
            'type': 'type',
            'line_appearance_id': 'lineAppearanceId',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._status = None
        self._user_id = None
        self._primary_edge = None
        self._secondary_edge = None
        self._type = None
        self._line_appearance_id = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Station.
        The globally unique identifier for the object.

        :return: The id of this Station.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Station.
        The globally unique identifier for the object.

        :param id: The id of this Station.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Station.


        :return: The name of this Station.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Station.


        :param name: The name of this Station.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Station.


        :return: The description of this Station.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Station.


        :param description: The description of this Station.
        :type: str
        """
        
        self._description = description

    @property
    def status(self):
        """
        Gets the status of this Station.


        :return: The status of this Station.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Station.


        :param status: The status of this Station.
        :type: str
        """
        allowed_values = ["AVAILABLE", "ASSOCIATED"]
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status`, must be one of {0}"
                .format(allowed_values)
            )

        self._status = status

    @property
    def user_id(self):
        """
        Gets the user_id of this Station.


        :return: The user_id of this Station.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this Station.


        :param user_id: The user_id of this Station.
        :type: str
        """
        
        self._user_id = user_id

    @property
    def primary_edge(self):
        """
        Gets the primary_edge of this Station.


        :return: The primary_edge of this Station.
        :rtype: UriReference
        """
        return self._primary_edge

    @primary_edge.setter
    def primary_edge(self, primary_edge):
        """
        Sets the primary_edge of this Station.


        :param primary_edge: The primary_edge of this Station.
        :type: UriReference
        """
        
        self._primary_edge = primary_edge

    @property
    def secondary_edge(self):
        """
        Gets the secondary_edge of this Station.


        :return: The secondary_edge of this Station.
        :rtype: UriReference
        """
        return self._secondary_edge

    @secondary_edge.setter
    def secondary_edge(self, secondary_edge):
        """
        Sets the secondary_edge of this Station.


        :param secondary_edge: The secondary_edge of this Station.
        :type: UriReference
        """
        
        self._secondary_edge = secondary_edge

    @property
    def type(self):
        """
        Gets the type of this Station.


        :return: The type of this Station.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Station.


        :param type: The type of this Station.
        :type: str
        """
        
        self._type = type

    @property
    def line_appearance_id(self):
        """
        Gets the line_appearance_id of this Station.


        :return: The line_appearance_id of this Station.
        :rtype: str
        """
        return self._line_appearance_id

    @line_appearance_id.setter
    def line_appearance_id(self, line_appearance_id):
        """
        Sets the line_appearance_id of this Station.


        :param line_appearance_id: The line_appearance_id of this Station.
        :type: str
        """
        
        self._line_appearance_id = line_appearance_id

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Station.
        The URI for this object

        :return: The self_uri of this Station.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Station.
        The URI for this object

        :param self_uri: The self_uri of this Station.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.analytics_api import AnalyticsApi


class TestAnalyticsApi(unittest.TestCase):
    """ AnalyticsApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.analytics_api.AnalyticsApi()

    def tearDown(self):
        pass

    def test_delete_reporting_schedules_schedule_id(self):
        """
        Test case for delete_reporting_schedules_schedule_id

        Delete a scheduled report job.
        """
        pass

    def test_get_conversations_conversation_id_details(self):
        """
        Test case for get_conversations_conversation_id_details

        Get a conversation by id
        """
        pass

    def test_get_reporting_metadata(self):
        """
        Test case for get_reporting_metadata

        Get list of reporting metadata.
        """
        pass

    def test_get_reporting_report_id_metadata(self):
        """
        Test case for get_reporting_report_id_metadata

        Get a reporting metadata.
        """
        pass

    def test_get_reporting_reportformats(self):
        """
        Test case for get_reporting_reportformats

        Get a list of report formats
        """
        pass

    def test_get_reporting_schedules(self):
        """
        Test case for get_reporting_schedules

        Get a list of scheduled report jobs
        """
        pass

    def test_get_reporting_schedules_schedule_id(self):
        """
        Test case for get_reporting_schedules_schedule_id

        Get a scheduled report job.
        """
        pass

    def test_get_reporting_schedules_schedule_id_history(self):
        """
        Test case for get_reporting_schedules_schedule_id_history

        Get list of completed scheduled report jobs.
        """
        pass

    def test_get_reporting_schedules_schedule_id_history_latest(self):
        """
        Test case for get_reporting_schedules_schedule_id_history_latest

        Get most recently completed scheduled report job.
        """
        pass

    def test_get_reporting_schedules_schedule_id_history_run_id(self):
        """
        Test case for get_reporting_schedules_schedule_id_history_run_id

        A completed scheduled report job
        """
        pass

    def test_get_reporting_timeperiods(self):
        """
        Test case for get_reporting_timeperiods

        Get a list of report time periods.
        """
        pass

    def test_post_conversations_aggregates_query(self):
        """
        Test case for post_conversations_aggregates_query

        Query for conversation aggregates
        """
        pass

    def test_post_conversations_conversation_id_details_properties(self):
        """
        Test case for post_conversations_conversation_id_details_properties

        Index conversation properties
        """
        pass

    def test_post_conversations_details_query(self):
        """
        Test case for post_conversations_details_query

        Query for conversation details
        """
        pass

    def test_post_evaluations_aggregates_query(self):
        """
        Test case for post_evaluations_aggregates_query

        Query for evaluation aggregates
        """
        pass

    def test_post_queues_observations_query(self):
        """
        Test case for post_queues_observations_query

        Query for queue observations
        """
        pass

    def test_post_reporting_schedules(self):
        """
        Test case for post_reporting_schedules

        Create a scheduled report job
        """
        pass

    def test_post_reporting_schedules_schedule_id_runreport(self):
        """
        Test case for post_reporting_schedules_schedule_id_runreport

        Place a scheduled report immediately into the reporting queue
        """
        pass

    def test_post_users_aggregates_query(self):
        """
        Test case for post_users_aggregates_query

        Query for user aggregates
        """
        pass

    def test_post_users_observations_query(self):
        """
        Test case for post_users_observations_query

        Query for user observations
        """
        pass

    def test_put_reporting_schedules_schedule_id(self):
        """
        Test case for put_reporting_schedules_schedule_id

        Update a scheduled report job.
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class ExtensionPool(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ExtensionPool - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'version': 'int',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'modified_by': 'str',
            'created_by': 'str',
            'state': 'str',
            'modified_by_app': 'str',
            'created_by_app': 'str',
            'start_number': 'str',
            'end_number': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'version': 'version',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'modified_by': 'modifiedBy',
            'created_by': 'createdBy',
            'state': 'state',
            'modified_by_app': 'modifiedByApp',
            'created_by_app': 'createdByApp',
            'start_number': 'startNumber',
            'end_number': 'endNumber',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._version = None
        self._date_created = None
        self._date_modified = None
        self._modified_by = None
        self._created_by = None
        self._state = None
        self._modified_by_app = None
        self._created_by_app = None
        self._start_number = None
        self._end_number = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this ExtensionPool.
        The globally unique identifier for the object.

        :return: The id of this ExtensionPool.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ExtensionPool.
        The globally unique identifier for the object.

        :param id: The id of this ExtensionPool.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ExtensionPool.


        :return: The name of this ExtensionPool.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ExtensionPool.


        :param name: The name of this ExtensionPool.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this ExtensionPool.


        :return: The description of this ExtensionPool.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ExtensionPool.


        :param description: The description of this ExtensionPool.
        :type: str
        """
        
        self._description = description

    @property
    def version(self):
        """
        Gets the version of this ExtensionPool.


        :return: The version of this ExtensionPool.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this ExtensionPool.


        :param version: The version of this ExtensionPool.
        :type: int
        """
        
        self._version = version

    @property
    def date_created(self):
        """
        Gets the date_created of this ExtensionPool.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this ExtensionPool.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this ExtensionPool.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this ExtensionPool.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this ExtensionPool.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this ExtensionPool.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this ExtensionPool.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this ExtensionPool.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def modified_by(self):
        """
        Gets the modified_by of this ExtensionPool.


        :return: The modified_by of this ExtensionPool.
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this ExtensionPool.


        :param modified_by: The modified_by of this ExtensionPool.
        :type: str
        """
        
        self._modified_by = modified_by

    @property
    def created_by(self):
        """
        Gets the created_by of this ExtensionPool.


        :return: The created_by of this ExtensionPool.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this ExtensionPool.


        :param created_by: The created_by of this ExtensionPool.
        :type: str
        """
        
        self._created_by = created_by

    @property
    def state(self):
        """
        Gets the state of this ExtensionPool.


        :return: The state of this ExtensionPool.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this ExtensionPool.


        :param state: The state of this ExtensionPool.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )

        self._state = state

    @property
    def modified_by_app(self):
        """
        Gets the modified_by_app of this ExtensionPool.


        :return: The modified_by_app of this ExtensionPool.
        :rtype: str
        """
        return self._modified_by_app

    @modified_by_app.setter
    def modified_by_app(self, modified_by_app):
        """
        Sets the modified_by_app of this ExtensionPool.


        :param modified_by_app: The modified_by_app of this ExtensionPool.
        :type: str
        """
        
        self._modified_by_app = modified_by_app

    @property
    def created_by_app(self):
        """
        Gets the created_by_app of this ExtensionPool.


        :return: The created_by_app of this ExtensionPool.
        :rtype: str
        """
        return self._created_by_app

    @created_by_app.setter
    def created_by_app(self, created_by_app):
        """
        Sets the created_by_app of this ExtensionPool.


        :param created_by_app: The created_by_app of this ExtensionPool.
        :type: str
        """
        
        self._created_by_app = created_by_app

    @property
    def start_number(self):
        """
        Gets the start_number of this ExtensionPool.
        The starting phone number for the range of this Extension pool. Must be in E.164 format

        :return: The start_number of this ExtensionPool.
        :rtype: str
        """
        return self._start_number

    @start_number.setter
    def start_number(self, start_number):
        """
        Sets the start_number of this ExtensionPool.
        The starting phone number for the range of this Extension pool. Must be in E.164 format

        :param start_number: The start_number of this ExtensionPool.
        :type: str
        """
        
        self._start_number = start_number

    @property
    def end_number(self):
        """
        Gets the end_number of this ExtensionPool.
        The ending phone number for the range of this Extension pool. Must be in E.164 format

        :return: The end_number of this ExtensionPool.
        :rtype: str
        """
        return self._end_number

    @end_number.setter
    def end_number(self, end_number):
        """
        Sets the end_number of this ExtensionPool.
        The ending phone number for the range of this Extension pool. Must be in E.164 format

        :param end_number: The end_number of this ExtensionPool.
        :type: str
        """
        
        self._end_number = end_number

    @property
    def self_uri(self):
        """
        Gets the self_uri of this ExtensionPool.
        The URI for this object

        :return: The self_uri of this ExtensionPool.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this ExtensionPool.
        The URI for this object

        :param self_uri: The self_uri of this ExtensionPool.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
NotificationsApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class NotificationsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def delete_channels_channel_id_subscriptions(self, channel_id, **kwargs):
        """
        Remove all subscriptions
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_channels_channel_id_subscriptions(channel_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str channel_id: Channel ID (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['channel_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_channels_channel_id_subscriptions" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'channel_id' is set
        if ('channel_id' not in params) or (params['channel_id'] is None):
            raise ValueError("Missing the required parameter `channel_id` when calling `delete_channels_channel_id_subscriptions`")


        resource_path = '/api/v2/notifications/channels/{channelId}/subscriptions'.replace('{format}', 'json')
        path_params = {}
        if 'channel_id' in params:
            path_params['channelId'] = params['channel_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='str',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_availabletopics(self, **kwargs):
        """
        Get available notification topics.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_availabletopics(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] expand: Which fields, if any, to expand
        :return: AvailableTopicEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['expand']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_availabletopics" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/notifications/availabletopics'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'expand' in params:
            query_params['expand'] = params['expand']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='AvailableTopicEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_channels(self, **kwargs):
        """
        The list of existing channels
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_channels(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: ChannelEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_channels" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/notifications/channels'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ChannelEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_channels_channel_id_subscriptions(self, channel_id, **kwargs):
        """
        The list of all subscriptions for this channel
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_channels_channel_id_subscriptions(channel_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str channel_id: Channel ID (required)
        :return: ChannelTopicEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['channel_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_channels_channel_id_subscriptions" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'channel_id' is set
        if ('channel_id' not in params) or (params['channel_id'] is None):
            raise ValueError("Missing the required parameter `channel_id` when calling `get_channels_channel_id_subscriptions`")


        resource_path = '/api/v2/notifications/channels/{channelId}/subscriptions'.replace('{format}', 'json')
        path_params = {}
        if 'channel_id' in params:
            path_params['channelId'] = params['channel_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ChannelTopicEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_channels(self, **kwargs):
        """
        Create a new channel
        There is a limit of 10 channels. Creating an 11th channel will remove the channel with oldest last used date.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_channels(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: Channel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_channels" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/notifications/channels'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Channel',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_channels_channel_id_subscriptions(self, channel_id, body, **kwargs):
        """
        Add a list of subscriptions to the existing list of subscriptions
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_channels_channel_id_subscriptions(channel_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str channel_id: Channel ID (required)
        :param list[ChannelTopic] body: Topic (required)
        :return: ChannelTopicEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['channel_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_channels_channel_id_subscriptions" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'channel_id' is set
        if ('channel_id' not in params) or (params['channel_id'] is None):
            raise ValueError("Missing the required parameter `channel_id` when calling `post_channels_channel_id_subscriptions`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_channels_channel_id_subscriptions`")


        resource_path = '/api/v2/notifications/channels/{channelId}/subscriptions'.replace('{format}', 'json')
        path_params = {}
        if 'channel_id' in params:
            path_params['channelId'] = params['channel_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ChannelTopicEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_channels_channel_id_subscriptions(self, channel_id, body, **kwargs):
        """
        Replace the current list of subscriptions with a new list.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_channels_channel_id_subscriptions(channel_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str channel_id: Channel ID (required)
        :param list[ChannelTopic] body: Topic (required)
        :return: ChannelTopicEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['channel_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_channels_channel_id_subscriptions" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'channel_id' is set
        if ('channel_id' not in params) or (params['channel_id'] is None):
            raise ValueError("Missing the required parameter `channel_id` when calling `put_channels_channel_id_subscriptions`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_channels_channel_id_subscriptions`")


        resource_path = '/api/v2/notifications/channels/{channelId}/subscriptions'.replace('{format}', 'json')
        path_params = {}
        if 'channel_id' in params:
            path_params['channelId'] = params['channel_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='ChannelTopicEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class CertificateDetails(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CertificateDetails - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'issuer': 'str',
            'subject': 'str',
            'expiration_date': 'datetime',
            'issue_date': 'datetime',
            'expired': 'bool',
            'signature_valid': 'bool',
            'valid': 'bool'
        }

        self.attribute_map = {
            'issuer': 'issuer',
            'subject': 'subject',
            'expiration_date': 'expirationDate',
            'issue_date': 'issueDate',
            'expired': 'expired',
            'signature_valid': 'signatureValid',
            'valid': 'valid'
        }

        self._issuer = None
        self._subject = None
        self._expiration_date = None
        self._issue_date = None
        self._expired = False
        self._signature_valid = False
        self._valid = False

    @property
    def issuer(self):
        """
        Gets the issuer of this CertificateDetails.
        Information about the issuer of the certificate.  The value of this property is a comma separated key=value format.  Each key is one of the attribute names supported by X.500.

        :return: The issuer of this CertificateDetails.
        :rtype: str
        """
        return self._issuer

    @issuer.setter
    def issuer(self, issuer):
        """
        Sets the issuer of this CertificateDetails.
        Information about the issuer of the certificate.  The value of this property is a comma separated key=value format.  Each key is one of the attribute names supported by X.500.

        :param issuer: The issuer of this CertificateDetails.
        :type: str
        """
        
        self._issuer = issuer

    @property
    def subject(self):
        """
        Gets the subject of this CertificateDetails.
        Information about the subject of the certificate.  The value of this property is a comma separated key=value format.  Each key is one of the attribute names supported by X.500.

        :return: The subject of this CertificateDetails.
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this CertificateDetails.
        Information about the subject of the certificate.  The value of this property is a comma separated key=value format.  Each key is one of the attribute names supported by X.500.

        :param subject: The subject of this CertificateDetails.
        :type: str
        """
        
        self._subject = subject

    @property
    def expiration_date(self):
        """
        Gets the expiration_date of this CertificateDetails.
        The expiration date of the certificate. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The expiration_date of this CertificateDetails.
        :rtype: datetime
        """
        return self._expiration_date

    @expiration_date.setter
    def expiration_date(self, expiration_date):
        """
        Sets the expiration_date of this CertificateDetails.
        The expiration date of the certificate. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param expiration_date: The expiration_date of this CertificateDetails.
        :type: datetime
        """
        
        self._expiration_date = expiration_date

    @property
    def issue_date(self):
        """
        Gets the issue_date of this CertificateDetails.
        The issue date of the certificate. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The issue_date of this CertificateDetails.
        :rtype: datetime
        """
        return self._issue_date

    @issue_date.setter
    def issue_date(self, issue_date):
        """
        Sets the issue_date of this CertificateDetails.
        The issue date of the certificate. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param issue_date: The issue_date of this CertificateDetails.
        :type: datetime
        """
        
        self._issue_date = issue_date

    @property
    def expired(self):
        """
        Gets the expired of this CertificateDetails.
        True if the certificate is expired, false otherwise.

        :return: The expired of this CertificateDetails.
        :rtype: bool
        """
        return self._expired

    @expired.setter
    def expired(self, expired):
        """
        Sets the expired of this CertificateDetails.
        True if the certificate is expired, false otherwise.

        :param expired: The expired of this CertificateDetails.
        :type: bool
        """
        
        self._expired = expired

    @property
    def signature_valid(self):
        """
        Gets the signature_valid of this CertificateDetails.


        :return: The signature_valid of this CertificateDetails.
        :rtype: bool
        """
        return self._signature_valid

    @signature_valid.setter
    def signature_valid(self, signature_valid):
        """
        Sets the signature_valid of this CertificateDetails.


        :param signature_valid: The signature_valid of this CertificateDetails.
        :type: bool
        """
        
        self._signature_valid = signature_valid

    @property
    def valid(self):
        """
        Gets the valid of this CertificateDetails.


        :return: The valid of this CertificateDetails.
        :rtype: bool
        """
        return self._valid

    @valid.setter
    def valid(self, valid):
        """
        Sets the valid of this CertificateDetails.


        :param valid: The valid of this CertificateDetails.
        :type: bool
        """
        
        self._valid = valid

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




from __future__ import absolute_import

# import models into sdk package
from .models.adfs import ADFS
from .models.actions import Actions
from .models.acw_settings import AcwSettings
from .models.agent import Agent
from .models.agent_activity import AgentActivity
from .models.agent_activity_entity_listing import AgentActivityEntityListing
from .models.agent_evaluator_activity import AgentEvaluatorActivity
from .models.aggregate_data_container import AggregateDataContainer
from .models.aggregate_metric_data import AggregateMetricData
from .models.aggregate_query_response import AggregateQueryResponse
from .models.aggregation_query import AggregationQuery
from .models.aggregation_range import AggregationRange
from .models.aggregation_result import AggregationResult
from .models.aggregation_result_entry import AggregationResultEntry
from .models.analytics_conversation import AnalyticsConversation
from .models.analytics_conversation_query_response import AnalyticsConversationQueryResponse
from .models.analytics_conversation_segment import AnalyticsConversationSegment
from .models.analytics_evaluation import AnalyticsEvaluation
from .models.analytics_participant import AnalyticsParticipant
from .models.analytics_property import AnalyticsProperty
from .models.analytics_query_aggregation import AnalyticsQueryAggregation
from .models.analytics_query_clause import AnalyticsQueryClause
from .models.analytics_query_filter import AnalyticsQueryFilter
from .models.analytics_query_predicate import AnalyticsQueryPredicate
from .models.analytics_session import AnalyticsSession
from .models.annotation import Annotation
from .models.archive_retention import ArchiveRetention
from .models.attachment import Attachment
from .models.attribute import Attribute
from .models.attribute_entity_listing import AttributeEntityListing
from .models.attribute_filter_item import AttributeFilterItem
from .models.attribute_query_request import AttributeQueryRequest
from .models.audit_change import AuditChange
from .models.audit_entity import AuditEntity
from .models.audit_entity_reference import AuditEntityReference
from .models.audit_facet import AuditFacet
from .models.audit_filter import AuditFilter
from .models.audit_message import AuditMessage
from .models.audit_search_result import AuditSearchResult
from .models.audit_user import AuditUser
from .models.available_language_list import AvailableLanguageList
from .models.available_topic import AvailableTopic
from .models.available_topic_entity_listing import AvailableTopicEntityListing
from .models.bullseye import Bullseye
from .models.calibration import Calibration
from .models.calibration_assignment import CalibrationAssignment
from .models.calibration_entity_listing import CalibrationEntityListing
from .models.call import Call
from .models.call_command import CallCommand
from .models.call_conversation import CallConversation
from .models.call_conversation_entity_listing import CallConversationEntityListing
from .models.call_forwarding import CallForwarding
from .models.call_media_participant import CallMediaParticipant
from .models.call_media_policy import CallMediaPolicy
from .models.call_media_policy_conditions import CallMediaPolicyConditions
from .models.call_record import CallRecord
from .models.callable_contacts_diagnostic import CallableContactsDiagnostic
from .models.callable_time import CallableTime
from .models.callable_time_set import CallableTimeSet
from .models.callable_time_set_entity_listing import CallableTimeSetEntityListing
from .models.callback import Callback
from .models.callback_conversation import CallbackConversation
from .models.callback_conversation_entity_listing import CallbackConversationEntityListing
from .models.callback_identifier import CallbackIdentifier
from .models.callback_media_participant import CallbackMediaParticipant
from .models.campaign import Campaign
from .models.campaign_diagnostics import CampaignDiagnostics
from .models.campaign_entity_listing import CampaignEntityListing
from .models.campaign_progress import CampaignProgress
from .models.campaign_schedule import CampaignSchedule
from .models.campaign_sequence import CampaignSequence
from .models.campaign_sequence_entity_listing import CampaignSequenceEntityListing
from .models.campaign_stats import CampaignStats
from .models.campaign_time_slot import CampaignTimeSlot
from .models.certificate import Certificate
from .models.certificate_authority_entity_listing import CertificateAuthorityEntityListing
from .models.certificate_details import CertificateDetails
from .models.change import Change
from .models.channel import Channel
from .models.channel_entity_listing import ChannelEntityListing
from .models.channel_topic import ChannelTopic
from .models.channel_topic_entity_listing import ChannelTopicEntityListing
from .models.chat import Chat
from .models.chat_conversation import ChatConversation
from .models.chat_conversation_entity_listing import ChatConversationEntityListing
from .models.chat_media_participant import ChatMediaParticipant
from .models.chat_media_policy import ChatMediaPolicy
from .models.chat_media_policy_conditions import ChatMediaPolicyConditions
from .models.chat_message import ChatMessage
from .models.chat_message_user import ChatMessageUser
from .models.command_status import CommandStatus
from .models.command_status_entity_listing import CommandStatusEntityListing
from .models.condition import Condition
from .models.connect_rate import ConnectRate
from .models.consult_transfer import ConsultTransfer
from .models.consult_transfer_response import ConsultTransferResponse
from .models.consult_transfer_update import ConsultTransferUpdate
from .models.contact import Contact
from .models.contact_callback_request import ContactCallbackRequest
from .models.contact_list import ContactList
from .models.contact_list_entity_listing import ContactListEntityListing
from .models.contact_phone_number_column import ContactPhoneNumberColumn
from .models.contact_sort import ContactSort
from .models.content_attribute_filter_item import ContentAttributeFilterItem
from .models.content_facet_filter_item import ContentFacetFilterItem
from .models.content_filter_item import ContentFilterItem
from .models.content_query_request import ContentQueryRequest
from .models.content_sort_item import ContentSortItem
from .models.conversation import Conversation
from .models.conversation_chat import ConversationChat
from .models.conversation_entity_listing import ConversationEntityListing
from .models.conversation_query import ConversationQuery
from .models.cover_sheet import CoverSheet
from .models.create_call_request import CreateCallRequest
from .models.create_call_response import CreateCallResponse
from .models.create_callback_command import CreateCallbackCommand
from .models.create_callback_response import CreateCallbackResponse
from .models.create_share_request import CreateShareRequest
from .models.create_share_request_member import CreateShareRequestMember
from .models.create_share_response import CreateShareResponse
from .models.create_user import CreateUser
from .models.customer_interaction_center import CustomerInteractionCenter
from .models.did import DID
from .models.did_entity_listing import DIDEntityListing
from .models.did_pool import DIDPool
from .models.did_pool_entity_listing import DIDPoolEntityListing
from .models.default_greeting_list import DefaultGreetingList
from .models.delete_retention import DeleteRetention
from .models.destination import Destination
from .models.detail import Detail
from .models.dialer_action import DialerAction
from .models.dialer_audit_request import DialerAuditRequest
from .models.dialer_contact import DialerContact
from .models.dialer_contact_entity_listing import DialerContactEntityListing
from .models.dialer_preview import DialerPreview
from .models.dialer_rule import DialerRule
from .models.digit_length import DigitLength
from .models.disconnect_reason import DisconnectReason
from .models.dnc_list import DncList
from .models.dnc_list_entity_listing import DncListEntityListing
from .models.document import Document
from .models.document_attribute import DocumentAttribute
from .models.document_audit import DocumentAudit
from .models.document_audit_entity_listing import DocumentAuditEntityListing
from .models.document_entity_listing import DocumentEntityListing
from .models.document_thumbnail import DocumentThumbnail
from .models.document_update import DocumentUpdate
from .models.document_upload import DocumentUpload
from .models.domain_capabilities import DomainCapabilities
from .models.domain_certificate_authority import DomainCertificateAuthority
from .models.domain_edge_software_update_dto import DomainEdgeSoftwareUpdateDto
from .models.domain_edge_software_version_dto import DomainEdgeSoftwareVersionDto
from .models.domain_entity import DomainEntity
from .models.domain_entity_listing import DomainEntityListing
from .models.domain_entity_listing_evaluation_form import DomainEntityListingEvaluationForm
from .models.domain_entity_listing_query_result import DomainEntityListingQueryResult
from .models.domain_logical_interface import DomainLogicalInterface
from .models.domain_network_address import DomainNetworkAddress
from .models.domain_network_command_response import DomainNetworkCommandResponse
from .models.domain_network_route import DomainNetworkRoute
from .models.domain_org_role_difference import DomainOrgRoleDifference
from .models.domain_organization_product import DomainOrganizationProduct
from .models.domain_organization_role import DomainOrganizationRole
from .models.domain_permission import DomainPermission
from .models.domain_permission_collection import DomainPermissionCollection
from .models.domain_permission_policy import DomainPermissionPolicy
from .models.domain_physical_capabilities import DomainPhysicalCapabilities
from .models.domain_physical_interface import DomainPhysicalInterface
from .models.domain_resource_condition_node import DomainResourceConditionNode
from .models.domain_resource_condition_value import DomainResourceConditionValue
from .models.domain_role import DomainRole
from .models.domain_schema_reference import DomainSchemaReference
from .models.download_response import DownloadResponse
from .models.duration_condition import DurationCondition
from .models.edge import Edge
from .models.edge_auto_update_config import EdgeAutoUpdateConfig
from .models.edge_entity_listing import EdgeEntityListing
from .models.edge_group import EdgeGroup
from .models.edge_group_entity_listing import EdgeGroupEntityListing
from .models.edge_interface import EdgeInterface
from .models.edge_line import EdgeLine
from .models.edge_line_entity_listing import EdgeLineEntityListing
from .models.edge_logs_job import EdgeLogsJob
from .models.edge_logs_job_file import EdgeLogsJobFile
from .models.edge_logs_job_request import EdgeLogsJobRequest
from .models.edge_logs_job_response import EdgeLogsJobResponse
from .models.edge_logs_job_upload_request import EdgeLogsJobUploadRequest
from .models.edge_version_information import EdgeVersionInformation
from .models.edge_version_report import EdgeVersionReport
from .models.email import Email
from .models.email_address import EmailAddress
from .models.email_attachment import EmailAttachment
from .models.email_conversation import EmailConversation
from .models.email_conversation_entity_listing import EmailConversationEntityListing
from .models.email_media_participant import EmailMediaParticipant
from .models.email_media_policy import EmailMediaPolicy
from .models.email_media_policy_conditions import EmailMediaPolicyConditions
from .models.email_message import EmailMessage
from .models.email_message_listing import EmailMessageListing
from .models.email_setup import EmailSetup
from .models.encryption_key import EncryptionKey
from .models.encryption_key_entity_listing import EncryptionKeyEntityListing
from .models.endpoint import Endpoint
from .models.endpoint_entity_listing import EndpointEntityListing
from .models.entry import Entry
from .models.error_body import ErrorBody
from .models.error_details import ErrorDetails
from .models.estimated_wait_time_predictions import EstimatedWaitTimePredictions
from .models.evaluation import Evaluation
from .models.evaluation_assignment import EvaluationAssignment
from .models.evaluation_entity_listing import EvaluationEntityListing
from .models.evaluation_form import EvaluationForm
from .models.evaluation_form_and_scoring_set import EvaluationFormAndScoringSet
from .models.evaluation_form_entity_listing import EvaluationFormEntityListing
from .models.evaluation_scoring_set import EvaluationScoringSet
from .models.evaluator_activity import EvaluatorActivity
from .models.evaluator_activity_entity_listing import EvaluatorActivityEntityListing
from .models.expansion_criterium import ExpansionCriterium
from .models.export_uri import ExportUri
from .models.extension import Extension
from .models.extension_entity_listing import ExtensionEntityListing
from .models.extension_pool import ExtensionPool
from .models.extension_pool_entity_listing import ExtensionPoolEntityListing
from .models.facet_entry import FacetEntry
from .models.facet_info import FacetInfo
from .models.facet_key_attribute import FacetKeyAttribute
from .models.facet_statistics import FacetStatistics
from .models.facet_term import FacetTerm
from .models.fax_document import FaxDocument
from .models.fax_document_entity_listing import FaxDocumentEntityListing
from .models.fax_send_request import FaxSendRequest
from .models.fax_send_response import FaxSendResponse
from .models.fax_summary import FaxSummary
from .models.geolocation import Geolocation
from .models.geolocation_settings import GeolocationSettings
from .models.greeting import Greeting
from .models.greeting_audio_file import GreetingAudioFile
from .models.greeting_media_info import GreetingMediaInfo
from .models.greeting_owner import GreetingOwner
from .models.group import Group
from .models.group_entity_listing import GroupEntityListing
from .models.group_members_update import GroupMembersUpdate
from .models.group_search_criteria import GroupSearchCriteria
from .models.group_search_request import GroupSearchRequest
from .models.groups_search_response import GroupsSearchResponse
from .models.import_status import ImportStatus
from .models.inbound_domain import InboundDomain
from .models.inbound_domain_entity_listing import InboundDomainEntityListing
from .models.inbound_route import InboundRoute
from .models.inbound_route_entity_listing import InboundRouteEntityListing
from .models.initiate_screen_recording import InitiateScreenRecording
from .models.interaction_stats_alert import InteractionStatsAlert
from .models.interaction_stats_alert_container import InteractionStatsAlertContainer
from .models.interaction_stats_rule import InteractionStatsRule
from .models.interaction_stats_rule_container import InteractionStatsRuleContainer
from .models.json_node import JsonNode
from .models.json_node_search_response import JsonNodeSearchResponse
from .models.key_rotation_schedule import KeyRotationSchedule
from .models.keyword import Keyword
from .models.keyword_set import KeywordSet
from .models.keyword_set_entity_listing import KeywordSetEntityListing
from .models.language import Language
from .models.language_entity_listing import LanguageEntityListing
from .models.library import Library
from .models.library_entity_listing import LibraryEntityListing
from .models.line import Line
from .models.line_base import LineBase
from .models.line_base_entity_listing import LineBaseEntityListing
from .models.line_entity_listing import LineEntityListing
from .models.line_status import LineStatus
from .models.location import Location
from .models.location_address import LocationAddress
from .models.location_emergency_number import LocationEmergencyNumber
from .models.location_search_criteria import LocationSearchCriteria
from .models.location_search_request import LocationSearchRequest
from .models.locations_search_response import LocationsSearchResponse
from .models.lock_info import LockInfo
from .models.logical_interface_entity_listing import LogicalInterfaceEntityListing
from .models.max_participants import MaxParticipants
from .models.media_participant_request import MediaParticipantRequest
from .models.media_policies import MediaPolicies
from .models.media_result import MediaResult
from .models.media_setting import MediaSetting
from .models.media_summary import MediaSummary
from .models.media_summary_detail import MediaSummaryDetail
from .models.member_entity import MemberEntity
from .models.metabase import Metabase
from .models.metered_evaluation_assignment import MeteredEvaluationAssignment
from .models.number import Number
from .models.number_plan import NumberPlan
from .models.numeric_range import NumericRange
from .models.o_auth_client import OAuthClient
from .models.o_auth_client_entity_listing import OAuthClientEntityListing
from .models.o_auth_provider import OAuthProvider
from .models.o_auth_provider_entity_listing import OAuthProviderEntityListing
from .models.observation_data_container import ObservationDataContainer
from .models.observation_query import ObservationQuery
from .models.observation_query_response import ObservationQueryResponse
from .models.okta import Okta
from .models.one_login import OneLogin
from .models.org_media_utilization import OrgMediaUtilization
from .models.organization import Organization
from .models.organization_presence import OrganizationPresence
from .models.organization_presence_entity_listing import OrganizationPresenceEntityListing
from .models.organization_product_entity_listing import OrganizationProductEntityListing
from .models.organization_role_entity_listing import OrganizationRoleEntityListing
from .models.orphan_recording import OrphanRecording
from .models.orphan_recording_listing import OrphanRecordingListing
from .models.out_of_office import OutOfOffice
from .models.outbound_route import OutboundRoute
from .models.outbound_route_entity_listing import OutboundRouteEntityListing
from .models.pin_configuration import PINConfiguration
from .models.paging_spec import PagingSpec
from .models.parameter import Parameter
from .models.parsed_certificate import ParsedCertificate
from .models.participant import Participant
from .models.participant_attributes import ParticipantAttributes
from .models.permission_collection_entity_listing import PermissionCollectionEntityListing
from .models.phone import Phone
from .models.phone_base import PhoneBase
from .models.phone_base_entity_listing import PhoneBaseEntityListing
from .models.phone_capabilities import PhoneCapabilities
from .models.phone_column import PhoneColumn
from .models.phone_entity_listing import PhoneEntityListing
from .models.phone_meta_base_entity_listing import PhoneMetaBaseEntityListing
from .models.phone_number_column import PhoneNumberColumn
from .models.phone_number_status import PhoneNumberStatus
from .models.phone_status import PhoneStatus
from .models.phones_reboot import PhonesReboot
from .models.physical_interface_entity_listing import PhysicalInterfaceEntityListing
from .models.policy import Policy
from .models.policy_actions import PolicyActions
from .models.policy_conditions import PolicyConditions
from .models.policy_entity_listing import PolicyEntityListing
from .models.policy_error_message import PolicyErrorMessage
from .models.policy_errors import PolicyErrors
from .models.prediction_results import PredictionResults
from .models.presence_query_response import PresenceQueryResponse
from .models.property_index_request import PropertyIndexRequest
from .models.provision_info import ProvisionInfo
from .models.pure_cloud import PureCloud
from .models.qualifier_mapping_observation_query_response import QualifierMappingObservationQueryResponse
from .models.quality_audit import QualityAudit
from .models.quality_audit_page import QualityAuditPage
from .models.query_facet_info import QueryFacetInfo
from .models.query_request import QueryRequest
from .models.query_result import QueryResult
from .models.query_results import QueryResults
from .models.question_group import QuestionGroup
from .models.question_group_score import QuestionGroupScore
from .models.question_score import QuestionScore
from .models.queue import Queue
from .models.queue_entity_listing import QueueEntityListing
from .models.queue_member import QueueMember
from .models.queue_utilization_diagnostic import QueueUtilizationDiagnostic
from .models.reaction import Reaction
from .models.recording import Recording
from .models.recording_email_message import RecordingEmailMessage
from .models.recording_settings import RecordingSettings
from .models.replace_request import ReplaceRequest
from .models.replace_response import ReplaceResponse
from .models.report_meta_data import ReportMetaData
from .models.report_meta_data_entity_listing import ReportMetaDataEntityListing
from .models.report_run_entry import ReportRunEntry
from .models.report_run_entry_entity_domain_listing import ReportRunEntryEntityDomainListing
from .models.report_schedule import ReportSchedule
from .models.report_schedule_entity_listing import ReportScheduleEntityListing
from .models.resource_condition_node import ResourceConditionNode
from .models.resource_condition_value import ResourceConditionValue
from .models.resource_permission_policy import ResourcePermissionPolicy
from .models.response import Response
from .models.response_entity_list import ResponseEntityList
from .models.response_entity_listing import ResponseEntityListing
from .models.response_filter import ResponseFilter
from .models.response_query_request import ResponseQueryRequest
from .models.response_query_results import ResponseQueryResults
from .models.response_set import ResponseSet
from .models.response_set_entity_listing import ResponseSetEntityListing
from .models.response_text import ResponseText
from .models.rest_error_detail import RestErrorDetail
from .models.retention_duration import RetentionDuration
from .models.ring import Ring
from .models.routing_data import RoutingData
from .models.routing_skill import RoutingSkill
from .models.routing_status import RoutingStatus
from .models.rule_set import RuleSet
from .models.rule_set_entity_listing import RuleSetEntityListing
from .models.run_now_response import RunNowResponse
from .models.salesforce import Salesforce
from .models.schedule_interval import ScheduleInterval
from .models.schema_category import SchemaCategory
from .models.schema_category_entity_listing import SchemaCategoryEntityListing
from .models.schema_reference_entity_listing import SchemaReferenceEntityListing
from .models.screen_recording_session import ScreenRecordingSession
from .models.screen_recording_session_listing import ScreenRecordingSessionListing
from .models.search_aggregation import SearchAggregation
from .models.search_criteria import SearchCriteria
from .models.search_request import SearchRequest
from .models.security_profile import SecurityProfile
from .models.security_profile_entity_listing import SecurityProfileEntityListing
from .models.segment import Segment
from .models.sequence_schedule import SequenceSchedule
from .models.server_date import ServerDate
from .models.service_context import ServiceContext
from .models.service_level import ServiceLevel
from .models.share import Share
from .models.share_entity_listing import ShareEntityListing
from .models.shared_entity import SharedEntity
from .models.site import Site
from .models.site_entity_listing import SiteEntityListing
from .models.skill_entity_listing import SkillEntityListing
from .models.skills_to_remove import SkillsToRemove
from .models.social_expression import SocialExpression
from .models.sort_item import SortItem
from .models.station import Station
from .models.station_entity_listing import StationEntityListing
from .models.statistical_response import StatisticalResponse
from .models.statistical_summary import StatisticalSummary
from .models.street_address import StreetAddress
from .models.subscriber_response import SubscriberResponse
from .models.suggest_search_criteria import SuggestSearchCriteria
from .models.suggest_search_request import SuggestSearchRequest
from .models.system_presence import SystemPresence
from .models.tag_query_request import TagQueryRequest
from .models.tag_value import TagValue
from .models.tag_value_entity_listing import TagValueEntityListing
from .models.term_attribute import TermAttribute
from .models.time_allowed import TimeAllowed
from .models.time_interval import TimeInterval
from .models.time_slot import TimeSlot
from .models.time_zone import TimeZone
from .models.time_zone_entity_listing import TimeZoneEntityListing
from .models.transfer_request import TransferRequest
from .models.trunk import Trunk
from .models.trunk_base import TrunkBase
from .models.trunk_base_assignment import TrunkBaseAssignment
from .models.trunk_entity_listing import TrunkEntityListing
from .models.trunk_metabase_entity_listing import TrunkMetabaseEntityListing
from .models.trunk_recording_enabled_count import TrunkRecordingEnabledCount
from .models.unread_metric import UnreadMetric
from .models.unread_status import UnreadStatus
from .models.uri_reference import UriReference
from .models.usage import Usage
from .models.usage_item import UsageItem
from .models.user import User
from .models.user_authorization import UserAuthorization
from .models.user_conversation_summary import UserConversationSummary
from .models.user_entity_listing import UserEntityListing
from .models.user_image import UserImage
from .models.user_me import UserMe
from .models.user_param import UserParam
from .models.user_presence import UserPresence
from .models.user_queue import UserQueue
from .models.user_queue_entity_listing import UserQueueEntityListing
from .models.user_recording import UserRecording
from .models.user_recording_entity_listing import UserRecordingEntityListing
from .models.user_routing_skill import UserRoutingSkill
from .models.user_search_criteria import UserSearchCriteria
from .models.user_search_request import UserSearchRequest
from .models.user_skill_entity_listing import UserSkillEntityListing
from .models.user_station import UserStation
from .models.user_stations import UserStations
from .models.users_entity_listing import UsersEntityListing
from .models.users_search_response import UsersSearchResponse
from .models.utilization import Utilization
from .models.validate_address_request import ValidateAddressRequest
from .models.validate_address_response import ValidateAddressResponse
from .models.video import Video
from .models.voicemail_mailbox_info import VoicemailMailboxInfo
from .models.voicemail_media_info import VoicemailMediaInfo
from .models.voicemail_message import VoicemailMessage
from .models.voicemail_message_entity_listing import VoicemailMessageEntityListing
from .models.voicemail_organization_policy import VoicemailOrganizationPolicy
from .models.voicemail_user_policy import VoicemailUserPolicy
from .models.workspace import Workspace
from .models.workspace_create import WorkspaceCreate
from .models.workspace_entity_listing import WorkspaceEntityListing
from .models.workspace_member import WorkspaceMember
from .models.workspace_member_entity_listing import WorkspaceMemberEntityListing
from .models.workspace_summary import WorkspaceSummary
from .models.wrap_up_code_mapping import WrapUpCodeMapping
from .models.wrapup import Wrapup
from .models.wrapup_code import WrapupCode
from .models.wrapup_code_entity_listing import WrapupCodeEntityListing

# import apis into sdk package
from .apis.alerting_api import AlertingApi
from .apis.analytics_api import AnalyticsApi
from .apis.attributes_api import AttributesApi
from .apis.authorization_api import AuthorizationApi
from .apis.configuration_api import ConfigurationApi
from .apis.content_management_api import ContentManagementApi
from .apis.conversations_api import ConversationsApi
from .apis.fax_api import FaxApi
from .apis.geolocation_api import GeolocationApi
from .apis.greetings_api import GreetingsApi
from .apis.groups_api import GroupsApi
from .apis.identity_provider_api import IdentityProviderApi
from .apis.languages_api import LanguagesApi
from .apis.locations_api import LocationsApi
from .apis.notifications_api import NotificationsApi
from .apis.o_auth_api import OAuthApi
from .apis.organization_api import OrganizationApi
from .apis.outbound_api import OutboundApi
from .apis.presence_api import PresenceApi
from .apis.quality_api import QualityApi
from .apis.recording_api import RecordingApi
from .apis.response_management_api import ResponseManagementApi
from .apis.routing_api import RoutingApi
from .apis.search_api import SearchApi
from .apis.stations_api import StationsApi
from .apis.suggest_api import SuggestApi
from .apis.telephony_providers_edge_api import TelephonyProvidersEdgeApi
from .apis.tokens_api import TokensApi
from .apis.user_recordings_api import UserRecordingsApi
from .apis.users_api import UsersApi
from .apis.utilities_api import UtilitiesApi
from .apis.voicemail_api import VoicemailApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class CreateCallbackCommand(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CreateCallbackCommand - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'script_id': 'str',
            'queue_id': 'str',
            'routing_data': 'RoutingData',
            'callback_user_name': 'str',
            'callback_numbers': 'list[str]',
            'callback_scheduled_time': 'datetime',
            'country_code': 'str',
            'is_automated': 'bool',
            'automated_callback_config_id': 'str',
            'data': 'dict(str, str)'
        }

        self.attribute_map = {
            'script_id': 'scriptId',
            'queue_id': 'queueId',
            'routing_data': 'routingData',
            'callback_user_name': 'callbackUserName',
            'callback_numbers': 'callbackNumbers',
            'callback_scheduled_time': 'callbackScheduledTime',
            'country_code': 'countryCode',
            'is_automated': 'isAutomated',
            'automated_callback_config_id': 'automatedCallbackConfigId',
            'data': 'data'
        }

        self._script_id = None
        self._queue_id = None
        self._routing_data = None
        self._callback_user_name = None
        self._callback_numbers = None
        self._callback_scheduled_time = None
        self._country_code = None
        self._is_automated = False
        self._automated_callback_config_id = None
        self._data = None

    @property
    def script_id(self):
        """
        Gets the script_id of this CreateCallbackCommand.
        The identifier of the script to be used for the callback

        :return: The script_id of this CreateCallbackCommand.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """
        Sets the script_id of this CreateCallbackCommand.
        The identifier of the script to be used for the callback

        :param script_id: The script_id of this CreateCallbackCommand.
        :type: str
        """
        
        self._script_id = script_id

    @property
    def queue_id(self):
        """
        Gets the queue_id of this CreateCallbackCommand.
        The identifier of the queue to be used for the callback. Either queueId or routingData is required.

        :return: The queue_id of this CreateCallbackCommand.
        :rtype: str
        """
        return self._queue_id

    @queue_id.setter
    def queue_id(self, queue_id):
        """
        Sets the queue_id of this CreateCallbackCommand.
        The identifier of the queue to be used for the callback. Either queueId or routingData is required.

        :param queue_id: The queue_id of this CreateCallbackCommand.
        :type: str
        """
        
        self._queue_id = queue_id

    @property
    def routing_data(self):
        """
        Gets the routing_data of this CreateCallbackCommand.
        The routing data to be used for the callback. Either queueId or routingData is required.

        :return: The routing_data of this CreateCallbackCommand.
        :rtype: RoutingData
        """
        return self._routing_data

    @routing_data.setter
    def routing_data(self, routing_data):
        """
        Sets the routing_data of this CreateCallbackCommand.
        The routing data to be used for the callback. Either queueId or routingData is required.

        :param routing_data: The routing_data of this CreateCallbackCommand.
        :type: RoutingData
        """
        
        self._routing_data = routing_data

    @property
    def callback_user_name(self):
        """
        Gets the callback_user_name of this CreateCallbackCommand.
        The name of the party to be called back.

        :return: The callback_user_name of this CreateCallbackCommand.
        :rtype: str
        """
        return self._callback_user_name

    @callback_user_name.setter
    def callback_user_name(self, callback_user_name):
        """
        Sets the callback_user_name of this CreateCallbackCommand.
        The name of the party to be called back.

        :param callback_user_name: The callback_user_name of this CreateCallbackCommand.
        :type: str
        """
        
        self._callback_user_name = callback_user_name

    @property
    def callback_numbers(self):
        """
        Gets the callback_numbers of this CreateCallbackCommand.
        A list of phone numbers for the callback.

        :return: The callback_numbers of this CreateCallbackCommand.
        :rtype: list[str]
        """
        return self._callback_numbers

    @callback_numbers.setter
    def callback_numbers(self, callback_numbers):
        """
        Sets the callback_numbers of this CreateCallbackCommand.
        A list of phone numbers for the callback.

        :param callback_numbers: The callback_numbers of this CreateCallbackCommand.
        :type: list[str]
        """
        
        self._callback_numbers = callback_numbers

    @property
    def callback_scheduled_time(self):
        """
        Gets the callback_scheduled_time of this CreateCallbackCommand.
        The scheduled date-time for the callback as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The callback_scheduled_time of this CreateCallbackCommand.
        :rtype: datetime
        """
        return self._callback_scheduled_time

    @callback_scheduled_time.setter
    def callback_scheduled_time(self, callback_scheduled_time):
        """
        Sets the callback_scheduled_time of this CreateCallbackCommand.
        The scheduled date-time for the callback as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param callback_scheduled_time: The callback_scheduled_time of this CreateCallbackCommand.
        :type: datetime
        """
        
        self._callback_scheduled_time = callback_scheduled_time

    @property
    def country_code(self):
        """
        Gets the country_code of this CreateCallbackCommand.
        The country code to be associated with the callback numbers.

        :return: The country_code of this CreateCallbackCommand.
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """
        Sets the country_code of this CreateCallbackCommand.
        The country code to be associated with the callback numbers.

        :param country_code: The country_code of this CreateCallbackCommand.
        :type: str
        """
        
        self._country_code = country_code

    @property
    def is_automated(self):
        """
        Gets the is_automated of this CreateCallbackCommand.
        Whether or not to automatically place a call for this callback.

        :return: The is_automated of this CreateCallbackCommand.
        :rtype: bool
        """
        return self._is_automated

    @is_automated.setter
    def is_automated(self, is_automated):
        """
        Sets the is_automated of this CreateCallbackCommand.
        Whether or not to automatically place a call for this callback.

        :param is_automated: The is_automated of this CreateCallbackCommand.
        :type: bool
        """
        
        self._is_automated = is_automated

    @property
    def automated_callback_config_id(self):
        """
        Gets the automated_callback_config_id of this CreateCallbackCommand.
        The id of the configuration to handle the response (e.g. live voice, machine) from automatically placing a call for a callback.

        :return: The automated_callback_config_id of this CreateCallbackCommand.
        :rtype: str
        """
        return self._automated_callback_config_id

    @automated_callback_config_id.setter
    def automated_callback_config_id(self, automated_callback_config_id):
        """
        Sets the automated_callback_config_id of this CreateCallbackCommand.
        The id of the configuration to handle the response (e.g. live voice, machine) from automatically placing a call for a callback.

        :param automated_callback_config_id: The automated_callback_config_id of this CreateCallbackCommand.
        :type: str
        """
        
        self._automated_callback_config_id = automated_callback_config_id

    @property
    def data(self):
        """
        Gets the data of this CreateCallbackCommand.
        A map of key-value pairs containing additional data that can be associated to the callback. These could be set up for instance to be used in a customized script shown during the call. Example: { \"notes\": \"ready to close the deal!\", \"customerPreferredName\": \"Doc\" }

        :return: The data of this CreateCallbackCommand.
        :rtype: dict(str, str)
        """
        return self._data

    @data.setter
    def data(self, data):
        """
        Sets the data of this CreateCallbackCommand.
        A map of key-value pairs containing additional data that can be associated to the callback. These could be set up for instance to be used in a customized script shown during the call. Example: { \"notes\": \"ready to close the deal!\", \"customerPreferredName\": \"Doc\" }

        :param data: The data of this CreateCallbackCommand.
        :type: dict(str, str)
        """
        
        self._data = data

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.authorization_api import AuthorizationApi


class TestAuthorizationApi(unittest.TestCase):
    """ AuthorizationApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.authorization_api.AuthorizationApi()

    def tearDown(self):
        pass

    def test_delete_roles_role_id(self):
        """
        Test case for delete_roles_role_id

        Delete an organization role.
        """
        pass

    def test_delete_user_id_roles(self):
        """
        Test case for delete_user_id_roles

        Removes all the roles from the user.
        """
        pass

    def test_get_permissions(self):
        """
        Test case for get_permissions

        Get all permissions.
        """
        pass

    def test_get_products(self):
        """
        Test case for get_products

        Get the list of enabled products
        """
        pass

    def test_get_roles(self):
        """
        Test case for get_roles

        Retrieve a list of all roles defined for the organization
        """
        pass

    def test_get_roles_leftrole_id_comparedefault_rightrole_id(self):
        """
        Test case for get_roles_leftrole_id_comparedefault_rightrole_id

        Get an org role to default role comparison comparison
        """
        pass

    def test_get_roles_role_id(self):
        """
        Test case for get_roles_role_id

        Get a single organization role.
        """
        pass

    def test_get_user_id_roles(self):
        """
        Test case for get_user_id_roles

        Returns a listing of roles and permissions for a user.
        """
        pass

    def test_patch_roles_role_id(self):
        """
        Test case for patch_roles_role_id

        Patch Organization Role for needsUpdate Field
        """
        pass

    def test_post_roles(self):
        """
        Test case for post_roles

        Create an organization role.
        """
        pass

    def test_post_roles_default(self):
        """
        Test case for post_roles_default

        Restores all default roles
        """
        pass

    def test_post_roles_leftrole_id_comparedefault_rightrole_id(self):
        """
        Test case for post_roles_leftrole_id_comparedefault_rightrole_id

        Get an unsaved org role to default role comparison
        """
        pass

    def test_put_roles_default(self):
        """
        Test case for put_roles_default

        Restore specified default roles
        """
        pass

    def test_put_roles_role_id(self):
        """
        Test case for put_roles_role_id

        Update an organization role.
        """
        pass

    def test_put_roles_role_id_users_add(self):
        """
        Test case for put_roles_role_id_users_add

        Sets the users for the role
        """
        pass

    def test_put_roles_role_id_users_remove(self):
        """
        Test case for put_roles_role_id_users_remove

        Removes the users from the role
        """
        pass

    def test_put_user_id_roles(self):
        """
        Test case for put_user_id_roles

        Sets the user's roles
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class SocialExpression(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SocialExpression - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'state': 'str',
            'id': 'str',
            'social_media_id': 'str',
            'social_media_hub': 'str',
            'social_user_name': 'str',
            'preview_text': 'str',
            'recording_id': 'str',
            'segments': 'list[Segment]',
            'held': 'bool',
            'disconnect_type': 'str',
            'start_hold_time': 'datetime',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime'
        }

        self.attribute_map = {
            'state': 'state',
            'id': 'id',
            'social_media_id': 'socialMediaId',
            'social_media_hub': 'socialMediaHub',
            'social_user_name': 'socialUserName',
            'preview_text': 'previewText',
            'recording_id': 'recordingId',
            'segments': 'segments',
            'held': 'held',
            'disconnect_type': 'disconnectType',
            'start_hold_time': 'startHoldTime',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime'
        }

        self._state = None
        self._id = None
        self._social_media_id = None
        self._social_media_hub = None
        self._social_user_name = None
        self._preview_text = None
        self._recording_id = None
        self._segments = None
        self._held = False
        self._disconnect_type = None
        self._start_hold_time = None
        self._connected_time = None
        self._disconnected_time = None

    @property
    def state(self):
        """
        Gets the state of this SocialExpression.


        :return: The state of this SocialExpression.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this SocialExpression.


        :param state: The state of this SocialExpression.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "NONE"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )

        self._state = state

    @property
    def id(self):
        """
        Gets the id of this SocialExpression.


        :return: The id of this SocialExpression.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SocialExpression.


        :param id: The id of this SocialExpression.
        :type: str
        """
        
        self._id = id

    @property
    def social_media_id(self):
        """
        Gets the social_media_id of this SocialExpression.


        :return: The social_media_id of this SocialExpression.
        :rtype: str
        """
        return self._social_media_id

    @social_media_id.setter
    def social_media_id(self, social_media_id):
        """
        Sets the social_media_id of this SocialExpression.


        :param social_media_id: The social_media_id of this SocialExpression.
        :type: str
        """
        
        self._social_media_id = social_media_id

    @property
    def social_media_hub(self):
        """
        Gets the social_media_hub of this SocialExpression.


        :return: The social_media_hub of this SocialExpression.
        :rtype: str
        """
        return self._social_media_hub

    @social_media_hub.setter
    def social_media_hub(self, social_media_hub):
        """
        Sets the social_media_hub of this SocialExpression.


        :param social_media_hub: The social_media_hub of this SocialExpression.
        :type: str
        """
        
        self._social_media_hub = social_media_hub

    @property
    def social_user_name(self):
        """
        Gets the social_user_name of this SocialExpression.


        :return: The social_user_name of this SocialExpression.
        :rtype: str
        """
        return self._social_user_name

    @social_user_name.setter
    def social_user_name(self, social_user_name):
        """
        Sets the social_user_name of this SocialExpression.


        :param social_user_name: The social_user_name of this SocialExpression.
        :type: str
        """
        
        self._social_user_name = social_user_name

    @property
    def preview_text(self):
        """
        Gets the preview_text of this SocialExpression.


        :return: The preview_text of this SocialExpression.
        :rtype: str
        """
        return self._preview_text

    @preview_text.setter
    def preview_text(self, preview_text):
        """
        Sets the preview_text of this SocialExpression.


        :param preview_text: The preview_text of this SocialExpression.
        :type: str
        """
        
        self._preview_text = preview_text

    @property
    def recording_id(self):
        """
        Gets the recording_id of this SocialExpression.


        :return: The recording_id of this SocialExpression.
        :rtype: str
        """
        return self._recording_id

    @recording_id.setter
    def recording_id(self, recording_id):
        """
        Sets the recording_id of this SocialExpression.


        :param recording_id: The recording_id of this SocialExpression.
        :type: str
        """
        
        self._recording_id = recording_id

    @property
    def segments(self):
        """
        Gets the segments of this SocialExpression.


        :return: The segments of this SocialExpression.
        :rtype: list[Segment]
        """
        return self._segments

    @segments.setter
    def segments(self, segments):
        """
        Sets the segments of this SocialExpression.


        :param segments: The segments of this SocialExpression.
        :type: list[Segment]
        """
        
        self._segments = segments

    @property
    def held(self):
        """
        Gets the held of this SocialExpression.


        :return: The held of this SocialExpression.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this SocialExpression.


        :param held: The held of this SocialExpression.
        :type: bool
        """
        
        self._held = held

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this SocialExpression.


        :return: The disconnect_type of this SocialExpression.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this SocialExpression.


        :param disconnect_type: The disconnect_type of this SocialExpression.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_FORWARD", "ERROR", "PEER", "OTHER"]
        if disconnect_type not in allowed_values:
            raise ValueError(
                "Invalid value for `disconnect_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._disconnect_type = disconnect_type

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this SocialExpression.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The start_hold_time of this SocialExpression.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this SocialExpression.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param start_hold_time: The start_hold_time of this SocialExpression.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this SocialExpression.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The connected_time of this SocialExpression.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this SocialExpression.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param connected_time: The connected_time of this SocialExpression.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this SocialExpression.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The disconnected_time of this SocialExpression.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this SocialExpression.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param disconnected_time: The disconnected_time of this SocialExpression.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.users_api import UsersApi


class TestUsersApi(unittest.TestCase):
    """ UsersApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.users_api.UsersApi()

    def tearDown(self):
        pass

    def test_delete_user_id(self):
        """
        Test case for delete_user_id

        Delete user
        """
        pass

    def test_delete_user_id_roles(self):
        """
        Test case for delete_user_id_roles

        Removes all the roles from the user.
        """
        pass

    def test_delete_user_id_routingskills_skill_id(self):
        """
        Test case for delete_user_id_routingskills_skill_id

        Remove routing skill from user
        """
        pass

    def test_delete_user_id_station_associatedstation(self):
        """
        Test case for delete_user_id_station_associatedstation

        Clear associated station
        """
        pass

    def test_delete_user_id_station_defaultstation(self):
        """
        Test case for delete_user_id_station_defaultstation

        Clear default station
        """
        pass

    def test_get_me(self):
        """
        Test case for get_me

        Get current user details.
        """
        pass

    def test_get_search(self):
        """
        Test case for get_search

        Search using q64
        """
        pass

    def test_get_user_id(self):
        """
        Test case for get_user_id

        Get user.
        """
        pass

    def test_get_user_id_callforwarding(self):
        """
        Test case for get_user_id_callforwarding

        Get a user's CallForwarding
        """
        pass

    def test_get_user_id_geolocations_client_id(self):
        """
        Test case for get_user_id_geolocations_client_id

        Get a user's Geolocation
        """
        pass

    def test_get_user_id_outofoffice(self):
        """
        Test case for get_user_id_outofoffice

        Get a OutOfOffice
        """
        pass

    def test_get_user_id_queues(self):
        """
        Test case for get_user_id_queues

        Get queues for user
        """
        pass

    def test_get_user_id_roles(self):
        """
        Test case for get_user_id_roles

        Returns a listing of roles and permissions for a user.
        """
        pass

    def test_get_user_id_routingskills(self):
        """
        Test case for get_user_id_routingskills

        List routing skills for user
        """
        pass

    def test_get_user_id_routingstatus(self):
        """
        Test case for get_user_id_routingstatus

        Fetch the routing status of a user
        """
        pass

    def test_get_user_id_station(self):
        """
        Test case for get_user_id_station

        Get station information for user
        """
        pass

    def test_get_users(self):
        """
        Test case for get_users

        Get the list of available users.
        """
        pass

    def test_patch_user_id(self):
        """
        Test case for patch_user_id

        Update user
        """
        pass

    def test_patch_user_id_callforwarding(self):
        """
        Test case for patch_user_id_callforwarding

        Patch a user's CallForwarding
        """
        pass

    def test_patch_user_id_geolocations_client_id(self):
        """
        Test case for patch_user_id_geolocations_client_id

        Patch a user's Geolocation
        """
        pass

    def test_patch_user_id_queues(self):
        """
        Test case for patch_user_id_queues

        Join or unjoin a set of queues for a user
        """
        pass

    def test_patch_user_id_queues_queue_id(self):
        """
        Test case for patch_user_id_queues_queue_id

        Join or unjoin a queue for a user
        """
        pass

    def test_post_search(self):
        """
        Test case for post_search

        Search
        """
        pass

    def test_post_user_id_routingskills(self):
        """
        Test case for post_user_id_routingskills

        Add routing skill to user
        """
        pass

    def test_post_users(self):
        """
        Test case for post_users

        Create user
        """
        pass

    def test_post_users_aggregates_query(self):
        """
        Test case for post_users_aggregates_query

        Query for user aggregates
        """
        pass

    def test_post_users_observations_query(self):
        """
        Test case for post_users_observations_query

        Query for user observations
        """
        pass

    def test_put_user_id_callforwarding(self):
        """
        Test case for put_user_id_callforwarding

        Update a user's CallForwarding
        """
        pass

    def test_put_user_id_outofoffice(self):
        """
        Test case for put_user_id_outofoffice

        Update an OutOfOffice
        """
        pass

    def test_put_user_id_roles(self):
        """
        Test case for put_user_id_roles

        Sets the user's roles
        """
        pass

    def test_put_user_id_routingskills_skill_id(self):
        """
        Test case for put_user_id_routingskills_skill_id

        Update routing skill proficiency or state.
        """
        pass

    def test_put_user_id_routingstatus(self):
        """
        Test case for put_user_id_routingstatus

        Update the routing status of a user
        """
        pass

    def test_put_user_id_station_associatedstation_station_id(self):
        """
        Test case for put_user_id_station_associatedstation_station_id

        Set associated station
        """
        pass

    def test_put_user_id_station_defaultstation_station_id(self):
        """
        Test case for put_user_id_station_defaultstation_station_id

        Set default station
        """
        pass


if __name__ == '__main__':
    unittest.main()